@@ -39,6 +39,61 @@ use crate::{License, CURRENT_FORMAT, KNOWN_FORMATS};
 use deb822_lossless::{Deb822, Paragraph};
 use std::path::Path;
 
+/// Decode deb822 paragraph markers in a multi-line field value.
+///
+/// According to Debian policy, blank lines in multi-line field values are
+/// represented as lines containing only "." (a single period). The deb822-lossless
+/// parser already strips the leading indentation whitespace from continuation lines,
+/// so we only need to decode the period markers back to blank lines.
+///
+/// # Arguments
+///
+/// * `text` - The raw field value text from deb822-lossless with indentation already stripped
+///
+/// # Returns
+///
+/// The decoded text with blank lines restored
+fn decode_field_text(text: &str) -> String {
+    text.lines()
+        .map(|line| {
+            if line == "." {
+                // Paragraph marker representing a blank line
+                ""
+            } else {
+                line
+            }
+        })
+        .collect::<Vec<_>>()
+        .join("\n")
+}
+
+/// Encode blank lines in a field value to deb822 paragraph markers.
+///
+/// According to Debian policy, blank lines in multi-line field values must be
+/// represented as lines containing only "." (a single period). The deb822-lossless
+/// library will reject values with actual blank lines, so we must encode them first.
+///
+/// # Arguments
+///
+/// * `text` - The decoded text with normal blank lines
+///
+/// # Returns
+///
+/// The encoded text with blank lines replaced by "."
+fn encode_field_text(text: &str) -> String {
+    text.lines()
+        .map(|line| {
+            if line.is_empty() {
+                // Blank line must be encoded as period marker
+                "."
+            } else {
+                line
+            }
+        })
+        .collect::<Vec<_>>()
+        .join("\n")
+}
+
 /// Field order for header paragraphs according to DEP-5 specification
 const HEADER_FIELD_ORDER: &[&str] = &[
     "Format",
@@ -561,19 +616,69 @@ impl LicenseParagraph {
     pub fn text(&self) -> Option<String> {
         self.0
             .get("License")
-            .and_then(|x| x.split_once('\n').map(|(_, text)| text.to_string()))
+            .and_then(|x| x.split_once('\n').map(|(_, text)| decode_field_text(text)))
+    }
+
+    /// Get the license as a License enum
+    pub fn license(&self) -> License {
+        let x = self.0.get("License").unwrap();
+        x.split_once('\n').map_or_else(
+            || License::Name(x.to_string()),
+            |(name, text)| {
+                let decoded_text = decode_field_text(text);
+                if name.is_empty() {
+                    License::Text(decoded_text)
+                } else {
+                    License::Named(name.to_string(), decoded_text)
+                }
+            },
+        )
     }
 
     /// Set the license
     pub fn set_license(&mut self, license: &License) {
         let text = match license {
             License::Name(name) => name.to_string(),
-            License::Named(name, text) => format!("{}\n{}", name, text),
-            License::Text(text) => text.to_string(),
+            License::Named(name, text) => format!("{}\n{}", name, encode_field_text(text)),
+            License::Text(text) => encode_field_text(text),
         };
         self.0
             .set_with_field_order("License", &text, LICENSE_FIELD_ORDER);
     }
+
+    /// Set just the license name (short name on the first line)
+    ///
+    /// If the license currently has text, it will be preserved.
+    /// If the license has no text, this will set it to just a name.
+    pub fn set_name(&mut self, name: &str) {
+        let current = self.license();
+        let new_license = match current {
+            License::Named(_, text) | License::Text(text) => License::Named(name.to_string(), text),
+            License::Name(_) => License::Name(name.to_string()),
+        };
+        self.set_license(&new_license);
+    }
+
+    /// Set just the license text (the full license text after the first line)
+    ///
+    /// If text is None, removes the license text while keeping the name.
+    /// If the license currently has a name, it will be preserved.
+    /// If the license has no name and text is Some, this will create a license with just text.
+    pub fn set_text(&mut self, text: Option<&str>) {
+        let current = self.license();
+        let new_license = match (current, text) {
+            (License::Named(name, _), Some(new_text)) | (License::Name(name), Some(new_text)) => {
+                License::Named(name, new_text.to_string())
+            }
+            (License::Named(name, _), None) | (License::Name(name), None) => License::Name(name),
+            (License::Text(_), Some(new_text)) => License::Text(new_text.to_string()),
+            (License::Text(_), None) => {
+                // Edge case: removing text from a text-only license. Set empty name.
+                License::Name(String::new())
+            }
+        };
+        self.set_license(&new_license);
+    }
 }
 
 #[cfg(test)]
@@ -1003,6 +1108,95 @@ License: GPL-3+
         assert_eq!(0, copyright.iter_files().count());
     }
 
+    #[test]
+    fn test_license_paragraph_set_name() {
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+
+License: GPL-3+
+ This is the GPL-3+ license text.
+"#;
+        let copyright = s.parse::<super::Copyright>().unwrap();
+        let mut license = copyright.iter_licenses().next().unwrap();
+
+        // Change just the name, preserving the text
+        license.set_name("Apache-2.0");
+
+        assert_eq!(license.name().unwrap(), "Apache-2.0");
+        assert_eq!(license.text().unwrap(), "This is the GPL-3+ license text.");
+    }
+
+    #[test]
+    fn test_license_paragraph_set_name_no_text() {
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+
+License: GPL-3+
+"#;
+        let copyright = s.parse::<super::Copyright>().unwrap();
+        let mut license = copyright.iter_licenses().next().unwrap();
+
+        // Change just the name when there's no text
+        license.set_name("MIT");
+
+        assert_eq!(license.license(), crate::License::Name("MIT".to_string()));
+        assert_eq!(license.text(), None);
+    }
+
+    #[test]
+    fn test_license_paragraph_set_text() {
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+
+License: GPL-3+
+ Old license text.
+"#;
+        let copyright = s.parse::<super::Copyright>().unwrap();
+        let mut license = copyright.iter_licenses().next().unwrap();
+
+        // Change just the text, preserving the name
+        license.set_text(Some("New license text."));
+
+        assert_eq!(license.name().unwrap(), "GPL-3+");
+        assert_eq!(license.text().unwrap(), "New license text.");
+    }
+
+    #[test]
+    fn test_license_paragraph_set_text_remove() {
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+
+License: GPL-3+
+ Old license text.
+"#;
+        let copyright = s.parse::<super::Copyright>().unwrap();
+        let mut license = copyright.iter_licenses().next().unwrap();
+
+        // Remove the text, keeping just the name
+        license.set_text(None);
+
+        assert_eq!(
+            license.license(),
+            crate::License::Name("GPL-3+".to_string())
+        );
+        assert_eq!(license.text(), None);
+    }
+
+    #[test]
+    fn test_license_paragraph_set_text_add() {
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+
+License: GPL-3+
+"#;
+        let copyright = s.parse::<super::Copyright>().unwrap();
+        let mut license = copyright.iter_licenses().next().unwrap();
+
+        // Add text to a name-only license
+        license.set_text(Some("This is the full GPL-3+ license text."));
+
+        assert_eq!(license.name().unwrap(), "GPL-3+");
+        assert_eq!(
+            license.text().unwrap(),
+            "This is the full GPL-3+ license text."
+        );
+    }
+
     #[test]
     fn test_files_paragraph_set_files() {
         let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
@@ -1100,4 +1294,147 @@ License: MIT
             output
         );
     }
+
+    #[test]
+    fn test_license_text_decoding_paragraph_markers() {
+        // Test that paragraph markers (.) are decoded to blank lines
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+
+License: MIT
+ Permission is hereby granted, free of charge, to any person obtaining a copy
+ of this software and associated documentation files.
+ .
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND.
+"#;
+        let copyright = s.parse::<super::Copyright>().expect("failed to parse");
+        let license_para = copyright
+            .iter_licenses()
+            .next()
+            .expect("no license paragraph");
+        let text = license_para.text().expect("no license text");
+
+        // The period marker should be decoded to a blank line
+        assert!(
+            text.contains("\n\n"),
+            "Expected blank line in decoded text, got: {:?}",
+            text
+        );
+        assert!(
+            !text.contains("\n.\n"),
+            "Period marker should be decoded, not present in output"
+        );
+
+        // Verify exact content
+        let expected = "Permission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND.";
+        assert_eq!(text, expected);
+    }
+
+    #[test]
+    fn test_license_enum_decoding() {
+        // Test that the license() method also decodes paragraph markers
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+
+License: GPL-3+
+ This program is free software.
+ .
+ You can redistribute it.
+"#;
+        let copyright = s.parse::<super::Copyright>().expect("failed to parse");
+        let license_para = copyright
+            .iter_licenses()
+            .next()
+            .expect("no license paragraph");
+        let license = license_para.license();
+
+        match license {
+            crate::License::Named(name, text) => {
+                assert_eq!(name, "GPL-3+");
+                assert!(text.contains("\n\n"), "Expected blank line in decoded text");
+                assert!(!text.contains("\n.\n"), "Period marker should be decoded");
+                assert_eq!(
+                    text,
+                    "This program is free software.\n\nYou can redistribute it."
+                );
+            }
+            _ => panic!("Expected Named license"),
+        }
+    }
+
+    #[test]
+    fn test_encode_field_text() {
+        // Test basic encoding of blank lines
+        let input = "line 1\n\nline 3";
+        let output = super::encode_field_text(input);
+        assert_eq!(output, "line 1\n.\nline 3");
+    }
+
+    #[test]
+    fn test_encode_decode_round_trip() {
+        // Test that encoding and decoding are inverse operations
+        let original = "First paragraph\n\nSecond paragraph\n\nThird paragraph";
+        let encoded = super::encode_field_text(original);
+        let decoded = super::decode_field_text(&encoded);
+        assert_eq!(
+            decoded, original,
+            "Round-trip encoding/decoding should preserve text"
+        );
+    }
+
+    #[test]
+    fn test_set_license_with_blank_lines() {
+        // Test that setting a license with blank lines encodes them properly
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+
+License: GPL-3+
+ Original text
+"#;
+        let copyright = s.parse::<super::Copyright>().expect("failed to parse");
+        let mut license_para = copyright
+            .iter_licenses()
+            .next()
+            .expect("no license paragraph");
+
+        // Set license text with blank lines
+        let new_license = crate::License::Named(
+            "GPL-3+".to_string(),
+            "First paragraph.\n\nSecond paragraph.".to_string(),
+        );
+        license_para.set_license(&new_license);
+
+        // Verify it was encoded properly in the raw deb822
+        let raw_text = copyright.to_string();
+        let expected_output = "Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/\n\nLicense: GPL-3+\n First paragraph.\n .\n Second paragraph.\n";
+        assert_eq!(raw_text, expected_output);
+
+        // Verify it decodes back correctly
+        let retrieved = license_para.text().expect("no text");
+        assert_eq!(retrieved, "First paragraph.\n\nSecond paragraph.");
+    }
+
+    #[test]
+    fn test_set_text_with_blank_lines() {
+        // Test that set_text also encodes blank lines
+        let s = r#"Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/
+
+License: MIT
+ Original text
+"#;
+        let copyright = s.parse::<super::Copyright>().expect("failed to parse");
+        let mut license_para = copyright
+            .iter_licenses()
+            .next()
+            .expect("no license paragraph");
+
+        // Set text with blank lines
+        license_para.set_text(Some("Line 1\n\nLine 2"));
+
+        // Verify encoding
+        let raw_text = copyright.to_string();
+        let expected_output = "Format: https://www.debian.org/doc/packaging-manuals/copyright-format/1.0/\n\nLicense: MIT\n Line 1\n .\n Line 2\n";
+        assert_eq!(raw_text, expected_output);
+
+        // Verify decoding
+        let retrieved = license_para.text().expect("no text");
+        assert_eq!(retrieved, "Line 1\n\nLine 2");
+    }
 }
